/*
 * \brief  Tpm connection
 * \author Jean-Adrien Domage <jean-adrien.domage@gapfruit.com>
 * \date   2021-06-24
 */

/*
 * Copyright (C) 2021 gapfruit AG
 */

#ifndef _INCLUDE__TPM__CONNECTION_H_
#define _INCLUDE__TPM__CONNECTION_H_

#include <base/connection.h>
#include <tpm_session/client.h>

namespace Tpm { struct Connection; }

struct Tpm::Connection : Genode::Connection<Session>, Session_client
{

	enum {
		RAM_QUOTA = 32 * 1024 * sizeof(long),
		DEFAULT_IO_BUFFER_SIZE = 8 * 1024,
	};

	explicit Connection(Genode::Env& env,  size_t io_buffer_size = DEFAULT_IO_BUFFER_SIZE, const char* label = "")
	:
		Genode::Connection<Session>(env,
		                            session(env.parent(),
		                                    "ram_quota=%ld, cap_quota=%ld, label=\"%s\", io_buffer_size=%ld",
		                                    RAM_QUOTA + io_buffer_size, Session::CAP_QUOTA, label, io_buffer_size)),
		Session_client(env.rm(), cap())
	{ }

};


#endif // _INCLUDE__TPM__CONNECTION_H_
